Crate nucel_sdk_api

Crate nucel_sdk_api 

Auto-generated Rust SDK for the nucel.dev REST API.

The contents of this crate are generated at build time by progenitor from openapi/nucel.json (the OpenAPI spec exported from the nucel-server utoipa annotations).

Usage

let client = nucel_sdk_api::new("https://nucel.dev", Some("ghp_token".into()))?;
let repo = client.get_repo().owner("acme").repo("widgets").send().await?;
println!("{}", repo.into_inner());

Modules

builder
Types for composing operation parameters.
prelude
Items consumers will typically use such as the Client.
types
Types used as operation parameters and responses.

Structs

ByteStream
Untyped byte stream used for both success and error responses.
Client
Client for Nucel API
ResponseValue
Typed value returned by generated client methods.

Enums

Error
Error produced by generated client methods.

Functions

new
Build a Client configured for base_url with an optional bearer token.